psicons.core

Package psicons :: Package core |
[hide private]
[frames] | no frames]

# Source Code for Package psicons.core

     1  #! /usr/bin/env python
     2  # -*- coding: utf-8 -*-
     3  """
     4  A hack to subvert the scons build system for scientific analysis.
     5
     6  Psicons allows scripts and external programs for analysis to be incorporated into
     7  a build procedure.  Every stage of analysis is a command-line call to a script
     8  or executable that takes *inputs* and produces *outputs*. When scons is called,
     9  dependencies between outputs and inputs are tested and only those stages are run
    10  that are necessary to update outputs. In addition, the exact sequence of
    11  analyses recorded by the build file.
    12  """
    13
    14  __docformat__ = 'restructuredtext en'
    15  __version__ = '0.1'
    16  __author__ = "Paul-Michael Agapow (pma@agapow.net)"
    17
    18
    19  ### IMPORTS ###
    20
    21  from commands import *
    22  from utils import *
    23
    24
    25  ### CONSTANTS & DEFINES ###
    26
    27  ### IMPLEMENTATION ###
    28
    29  ## DEBUG & TEST ###
    30
    31  if __name__ == "__main__":
    32          import doctest
    33          doctest.testmod()
    34
    35
    36
    37  ### END #######################################################################
    38